Learn R Programming

jenga (version 1.3.0)

covid_in_europe: covid_in_europe data set

Description

A data frame with with daily and cumulative cases of Covid infections and deaths in Europe since March 2021.

Usage

covid_in_europe

Arguments

Format

A data frame with 5 columns and 163 rows.